Balsam Executor - Remote apps
=============================

.. automodule:: balsam_executor
  :no-undoc-members:

.. autoclass:: BalsamExecutor
  :show-inheritance:
  :members: __init__, register_app, submit_allocation, revoke_allocation, submit

.. autoclass:: BalsamTask
  :show-inheritance:
  :member-order: bysource
  :members: poll, wait, kill
